var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { useState, useEffect, useMemo, useRef } from 'react';
import { getInitial, getValue, getErrors } from './utils';
import { ajv } from './utils/validation';
import { useDebounce } from './Hooks/useDebounce';
var useAJVForm = function (initial, schema, errors) {
    var initialStateRef = useRef(getInitial(initial));
    var _a = useState(getInitial(initial)), state = _a[0], setState = _a[1];
    var AJVValidate = ajv.compile(schema);
    var _b = useState(null), currentField = _b[0], setCurrentField = _b[1];
    var _c = useState(0), editCounter = _c[0], setEditCounter = _c[1];
    var debouncedField = useDebounce(currentField, 500);
    var resetForm = function () {
        setState(Object.keys(state).reduce(function (acc, name) {
            var _a;
            return __assign(__assign({}, acc), (_a = {}, _a[name] = {
                value: '',
                error: '',
            }, _a));
        }, {}));
    };
    var validateField = function (fieldName) {
        var _a;
        var isValid = AJVValidate((_a = {}, _a[fieldName] = state[fieldName].value, _a));
        var errors = AJVValidate.errors || [];
        var fieldErrors = isValid ? {} : getErrors(errors);
        var error = isDirty ? fieldErrors[fieldName] || '' : '';
        setState(function (prevState) {
            var _a;
            return (__assign(__assign({}, prevState), (_a = {}, _a[fieldName] = __assign(__assign({}, prevState[fieldName]), { error: error }), _a)));
        });
    };
    var handleBlur = function (fieldName) {
        validateField(fieldName);
    };
    var setFormState = function (form) {
        setState(function (current) {
            var name = Object.keys(form)[0];
            var state = __assign({}, current);
            state[name] = __assign(__assign({}, state[name]), { value: getValue(form[name]), error: '' });
            setCurrentField({ name: name, editId: editCounter });
            setEditCounter(editCounter + 1);
            return state;
        });
    };
    var setErrors = function (errors) {
        return Object.keys(errors).reduce(function (acc, fieldName) {
            var _a;
            var key = fieldName;
            return __assign(__assign({}, acc), (_a = {}, _a[fieldName] = {
                value: getValue(state[key].value),
                error: errors[fieldName] || '',
            }, _a));
        }, __assign({}, state));
    };
    var validateForm = function () {
        try {
            var data = Object.keys(state).reduce(function (acc, inputName) {
                var _a;
                return __assign(__assign({}, acc), (_a = {}, _a[inputName] = getValue(state[inputName].value), _a));
            }, {});
            if (!AJVValidate(data) && AJVValidate.errors) {
                var errors_1 = getErrors(AJVValidate.errors);
                setState(setErrors(Object.keys(errors_1).reduce(function (acc, fieldName) {
                    var _a;
                    return __assign(__assign({}, acc), (_a = {}, _a[fieldName] = getValue(errors_1[fieldName]), _a));
                }, {})));
                return { isValid: false, data: null };
            }
            return { isValid: true, data: data };
        }
        catch (error) {
            return { isValid: false, data: null };
        }
    };
    var isFormDirty = function (currentState, initialState) {
        return Object.keys(currentState).some(function (key) { return currentState[key].value !== initialState[key].value; });
    };
    var isDirty = useMemo(function () { return isFormDirty(state, initialStateRef.current); }, [state]);
    useEffect(function () {
        if (debouncedField) {
            validateField(debouncedField.name);
        }
    }, [debouncedField]);
    useEffect(function () {
        if (!(errors === null || errors === void 0 ? void 0 : errors.length)) {
            return;
        }
        setState(setErrors(getErrors(errors)));
    }, [errors]);
    return {
        reset: resetForm,
        set: setFormState,
        validate: validateForm,
        onBlur: handleBlur,
        isDirty: isDirty,
        state: state,
    };
};
export default useAJVForm;
//# sourceMappingURL=index.js.map