var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { act, renderHook } from '@testing-library/react-hooks';
import useAJVForm from '.';
import { vi } from 'vitest';
beforeEach(function () {
    vi.useFakeTimers();
});
afterEach(function () {
    vi.restoreAllMocks();
});
describe('useAJVForm', function () {
    it('initializes correctly', function () {
        var initialData = {
            title: 'Hi, World',
        };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string' },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        expect(result.current.state).toEqual({
            title: { value: 'Hi, World', error: '' },
        });
    });
    it('handles onChange event correctly', function () {
        var initialData = { title: '' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string' },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ title: 'New Title' });
        expect(result.current.state.title.value).toBe('New Title');
    });
    it('handles onBlur event with validation correctly', function () {
        var initialData = { title: '' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string' },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ title: '' });
        result.current.onBlur('title');
        expect(result.current.state.title.error).toEqual('');
    });
    it('correctly identifies when the form is dirty', function () {
        var initialData = { title: 'Original Title' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string' },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        expect(result.current.isDirty).toBe(false);
        result.current.set({ title: 'Changed Title' });
        expect(result.current.isDirty).toBe(true);
    });
    it('resets the form correctly', function () {
        var initialData = { title: 'Hello' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string' },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        act(function () {
            result.current.set({ title: 'New Title' });
        });
        result.current.reset();
        expect(result.current.state.title.value).toBe('');
    });
    it('validates the form correctly', function () {
        var initialData = { title: '' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string' },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ title: '' });
        var validation = result.current.validate();
        expect(validation.isValid).toBe(true);
    });
    it('validates minLength and maxLength for title', function () {
        var initialData = { title: '' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string', minLength: 3, maxLength: 10 },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ title: 'Lo' });
        result.current.onBlur('title');
        expect(result.current.state.title.error).toContain('Should be at least 3 characters long.');
        result.current.set({ title: 'Lorem ipsum hi world' });
        result.current.onBlur('title');
        expect(result.current.state.title.error).toContain('Should not exceed 10 characters.');
    });
    it('validates secure-string custom ajv validator', function () {
        var initialData = { title: '' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: {
                    type: 'string',
                    'secure-string': true,
                },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ title: 'Hello, world ++++' });
        result.current.onBlur('title');
        expect(result.current.state.title.error).toContain('The string contains characters that are not alphanumeric, a dash, an exclamation mark, a question mark, an underscore, or a space');
    });
    it('validates is-youtube-url custom ajv validator', function () {
        var initialData = { videoURL: '' };
        var schema = {
            type: 'object',
            required: ['videoURL'],
            properties: {
                videoURL: {
                    type: 'string',
                    'is-youtube-url': true,
                },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ videoURL: 'dsdsds' });
        result.current.onBlur('videoURL');
        expect(result.current.state.videoURL.error).toContain('Invalid YouTube URL');
    });
    it('debounces validation on change event', function () { return __awaiter(void 0, void 0, void 0, function () {
        var initialData, schema, result;
        return __generator(this, function (_a) {
            initialData = { title: '' };
            schema = {
                type: 'object',
                required: ['title'],
                properties: {
                    title: { type: 'string', minLength: 3 },
                },
            };
            result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
            result.current.set({ title: 'Hi' });
            act(function () {
                vi.advanceTimersByTime(500);
            });
            expect(result.current.state.title.error).not.toBe('');
            return [2 /*return*/];
        });
    }); });
    it('validates immediately on blur event', function () {
        var initialData = { title: '' };
        var schema = {
            type: 'object',
            required: ['title'],
            properties: {
                title: { type: 'string', minLength: 3 },
            },
        };
        var result = renderHook(function () { return useAJVForm(initialData, schema); }).result;
        result.current.set({ title: 'Hi' });
        result.current.onBlur('title');
        expect(result.current.state.title.error).toBe('Should be at least 3 characters long.');
    });
});
//# sourceMappingURL=useAjvForm.test.js.map